@@ -40,7 +40,7 @@ from flux.constraint.parser import ConstraintParser, ConstraintSyntaxError
 from flux.idset import IDset
 from flux.job import JobspecV1, JobWatcher
 from flux.progress import ProgressBar
-from flux.util import dict_merge, set_treedict
+from flux.util import dict_merge, get_treedict, set_treedict
 
 LOGGER = logging.getLogger("flux")
 
@@ -63,7 +63,7 @@ def decode_signal(val):
     try:
         return getattr(signal, f"SIG{val}")
     except AttributeError:
-        pass
+        pass  # Fall through to raise ValueError
     raise ValueError(f"signal '{val}' is invalid")
 
 
@@ -422,7 +422,10 @@ class BatchConfig:
             value = json.loads(value)
         except json.decoder.JSONDecodeError:
             value = str(value)
-        set_treedict(self.config, key, value)
+        try:
+            set_treedict(self.config, key, value)
+        except TypeError as e:
+            raise TypeError(f"failed to set {key} to {value}: {e}")
         return self
 
     def update_file(self, path, extension=".toml"):
@@ -493,6 +496,12 @@ class BatchConfig:
             return self.update_file(value, extension)
         return self.update_named_config(value)
 
+    def get(self, key, default=None):
+        """
+        Get a value from the current config using dotted key form
+        """
+        return get_treedict(self.config or {}, key, default=default)
+
 
 class ConfAction(argparse.Action):
     """Handle batch/alloc --conf option"""
@@ -544,7 +553,6 @@ class Xcmd:
         "flags": "--flags=",
         "begin_time": "--begin-time=",
         "signal": "--signal=",
-        "taskmap": "--taskmap=",
     }
 
     class Xinput:
@@ -734,6 +742,7 @@ def parse_jobspec_keyval(label, keyval):
         try:
             val = json.loads(val)
         except (json.JSONDecodeError, TypeError):
+            # val was not a JSON string, keep as is
             pass
     return key, val
 
@@ -1015,7 +1024,6 @@ class MiniCmd:
             # shell options dict and will be processed by the shell.
             jobspec.setattr_shell_option("env-expand", env_expand)
 
-        jobspec.cwd = args.cwd if args.cwd is not None else os.getcwd()
         rlimits = get_filtered_rlimits(args.rlimit)
         if rlimits:
             jobspec.setattr_shell_option("rlimit", rlimits)
@@ -1042,46 +1050,6 @@ class MiniCmd:
                 )
             except ConstraintSyntaxError as exc:
                 raise ValueError(f"--requires='{constraint}': {exc}")
-        if args.time_limit is not None:
-            #  With no units, time_limit is in minutes, but jobspec.duration
-            #  takes seconds or FSD by default, so convert here if necessary.
-            try:
-                limit = float(args.time_limit)
-                args.time_limit = limit * 60
-            except ValueError:
-                pass
-            jobspec.duration = args.time_limit
-
-        if args.job_name is not None:
-            jobspec.setattr("system.job.name", args.job_name)
-
-        if args.input is not None:
-            #  Note: temporary stopgap until per-task input is supported
-            #  by the job shell:
-            #  Check if --input specified an IDset. If not, then assume
-            #  a file, otherwise, do not modify jobspec, input will be
-            #  handled by `flux job attach`.
-            try:
-                IDset(args.input)
-            except (ValueError, OSError):
-                jobspec.stdin = args.input
-
-        if args.output is not None and args.output not in ["none", "kvs"]:
-            jobspec.stdout = args.output
-            if args.label_io:
-                jobspec.setattr_shell_option("output.stdout.label", True)
-
-        if args.error is not None:
-            jobspec.stderr = args.error
-            if args.label_io:
-                jobspec.setattr_shell_option("output.stderr.label", True)
-
-        if args.unbuffered:
-            #  For output, set the buffer.type to none and reduce the configured
-            #  event batch-timeout to something very small.
-            jobspec.setattr_shell_option("output.stdout.buffer.type", "none")
-            jobspec.setattr_shell_option("output.stderr.buffer.type", "none")
-            jobspec.setattr_shell_option("output.batch-timeout", 0.05)
 
         if args.setopt is not None:
             for keyval in args.setopt:
@@ -1095,12 +1063,6 @@ class MiniCmd:
             # if stop-tasks-in-exec is present, overwrite
             jobspec.setattr_shell_option("stop-tasks-in-exec", json.loads("1"))
 
-        if args.queue is not None:
-            jobspec.setattr("system.queue", args.queue)
-
-        if args.bank is not None:
-            jobspec.setattr("system.bank", args.bank)
-
         if args.setattr is not None:
             for keyval in args.setattr:
                 key, val = parse_jobspec_keyval("--setattr", keyval)
@@ -1275,6 +1237,27 @@ class SubmitBaseCmd(MiniCmd):
         if args.command[0] == "--":
             args.command.pop(0)
 
+        #  Time limit in cli submission commands defaults to minutes if
+        #  no units are given, but JobspecV1 duration is in seconds or FSD,
+        #  so convert if necessary:
+        if args.time_limit is not None:
+            try:
+                limit = float(args.time_limit)
+                args.time_limit = limit * 60
+            except ValueError:
+                # no conversion necessary
+                pass
+
+        #  Check if --input specified an IDset. If not, then assume a file,
+        #  otherwise do not modify jobspec, input will be handled by
+        #  `flux job attach`:
+        stdin = None
+        if args.input is not None:
+            try:
+                IDset(args.input)
+            except (ValueError, OSError):
+                stdin = args.input
+
         #  Ensure integer args are converted to int() here.
         #  This is done because we do not use type=int in argparse in order
         #   to allow these options to be mutable for bulksubmit:
@@ -1357,6 +1340,16 @@ class SubmitBaseCmd(MiniCmd):
                 per_resource_count=per_resource_count,
                 gpus_per_node=args.gpus_per_node,
                 exclusive=args.exclusive,
+                duration=args.time_limit,
+                cwd=args.cwd if args.cwd is not None else os.getcwd(),
+                name=args.job_name,
+                input=stdin,
+                output=args.output,
+                error=args.error,
+                label_io=args.label_io,
+                unbuffered=args.unbuffered,
+                queue=args.queue,
+                bank=args.bank,
             )
 
         #  If ntasks not set, then set it to node count, with
@@ -1380,6 +1373,16 @@ class SubmitBaseCmd(MiniCmd):
             gpus_per_task=args.gpus_per_task,
             num_nodes=args.nodes,
             exclusive=args.exclusive,
+            duration=args.time_limit,
+            cwd=args.cwd if args.cwd is not None else os.getcwd(),
+            name=args.job_name,
+            input=stdin,
+            output=args.output,
+            error=args.error,
+            label_io=args.label_io,
+            unbuffered=args.unbuffered,
+            queue=args.queue,
+            bank=args.bank,
         )
 
     def run_and_exit(self):
@@ -1649,71 +1652,128 @@ class SubmitBulkCmd(SubmitBaseCmd):
         self.run_and_exit()
 
 
-def add_batch_alloc_args(parser):
-    """
-    Add "batch"-specific resource allocation arguments to parser object
-    which deal in slots instead of tasks.
-    """
-    parser.add_argument(
-        "--conf",
-        metavar="CONF",
-        default=BatchConfig(),
-        action=ConfAction,
-        help="Set configuration for a child Flux instance. CONF may be a "
-        + "multiline string in JSON or TOML, a configuration key=value, a "
-        + "path to a JSON or TOML file, or a configuration loaded by name "
-        + "from a standard search path. This option may specified multiple "
-        + "times, in which case the config is iteratively updated.",
-    )
-    parser.add_argument(
-        "--broker-opts",
-        metavar="OPTS",
-        default=None,
-        action="append",
-        help="Pass options to flux brokers",
-    )
-    parser.add_argument(
-        "--dump",
-        nargs="?",
-        const="flux-{{jobid}}-dump.tgz",
-        metavar="FILE",
-        help="Archive KVS on exit",
-    )
-    parser.add_argument(
-        "-n",
-        "--nslots",
-        type=int,
-        metavar="N",
-        help="Number of total resource slots requested."
-        + " The size of a resource slot may be specified via the"
-        + " -c, --cores-per-slot and -g, --gpus-per-slot options."
-        + " The default slot size is 1 core.",
-    )
-    parser.add_argument(
-        "-c",
-        "--cores-per-slot",
-        type=int,
-        metavar="N",
-        default=1,
-        help="Number of cores to allocate per slot",
-    )
-    parser.add_argument(
-        "-g",
-        "--gpus-per-slot",
-        type=int,
-        metavar="N",
-        help="Number of GPUs to allocate per slot",
-    )
-    parser.add_argument(
-        "-N",
-        "--nodes",
-        type=int,
-        metavar="N",
-        help="Distribute allocated resource slots across N individual nodes",
-    )
-    parser.add_argument(
-        "-x",
-        "--exclusive",
-        action="store_true",
-        help="With -N, --nodes, allocate nodes exclusively",
-    )
+class BatchAllocCmd(MiniCmd):
+    def __init__(self, prog, usage=None, description=None, exclude_io=True):
+        self.t0 = None
+        super().__init__(prog, usage, description, exclude_io)
+        self.parser.add_argument(
+            "--add-brokers", default=0, type=int, help=argparse.SUPPRESS
+        )
+        self.parser.add_argument(
+            "--conf",
+            metavar="CONF",
+            default=BatchConfig(),
+            action=ConfAction,
+            help="Set configuration for a child Flux instance. CONF may be a "
+            + "multiline string in JSON or TOML, a configuration key=value, a "
+            + "path to a JSON or TOML file, or a configuration loaded by name "
+            + "from a standard search path. This option may specified multiple "
+            + "times, in which case the config is iteratively updated.",
+        )
+        self.parser.add_argument(
+            "--broker-opts",
+            metavar="OPTS",
+            default=None,
+            action="append",
+            help="Pass options to flux brokers",
+        )
+        self.parser.add_argument(
+            "--dump",
+            nargs="?",
+            const="flux-{{jobid}}-dump.tgz",
+            metavar="FILE",
+            help="Archive KVS on exit",
+        )
+        self.parser.add_argument(
+            "-n",
+            "--nslots",
+            type=int,
+            metavar="N",
+            help="Number of total resource slots requested."
+            + " The size of a resource slot may be specified via the"
+            + " -c, --cores-per-slot and -g, --gpus-per-slot options."
+            + " The default slot size is 1 core.",
+        )
+        self.parser.add_argument(
+            "-c",
+            "--cores-per-slot",
+            type=int,
+            metavar="N",
+            default=1,
+            help="Number of cores to allocate per slot",
+        )
+        self.parser.add_argument(
+            "-g",
+            "--gpus-per-slot",
+            type=int,
+            metavar="N",
+            help="Number of GPUs to allocate per slot",
+        )
+        self.parser.add_argument(
+            "-N",
+            "--nodes",
+            type=int,
+            metavar="N",
+            help="Distribute allocated resource slots across N individual nodes",
+        )
+        self.parser.add_argument(
+            "-x",
+            "--exclusive",
+            action="store_true",
+            help="With -N, --nodes, allocate nodes exclusively",
+        )
+
+    def init_common(self, args):
+        """Common initialization code for batch/alloc"""
+        #  If number of slots not specified, then set it to node count
+        #   if set, otherwise raise an error.
+        if not args.nslots:
+            if not args.nodes:
+                raise ValueError("Number of slots to allocate must be specified")
+            args.nslots = args.nodes
+            args.exclusive = True
+
+        if args.dump:
+            args.broker_opts = args.broker_opts or []
+            args.broker_opts.append("-Scontent.dump=" + args.dump)
+
+        if args.add_brokers > 0:
+            if not args.nodes:
+                raise ValueError(
+                    "--add-brokers may only be specified with -N, --nnodes"
+                )
+            nbrokers = args.add_brokers
+            nnodes = args.nodes
+
+            # Force update taskmap with extra ranks on nodeid 0:
+            args.taskmap = f"manual:[[0,1,{1+nbrokers},1],[1,{nnodes-1},1,1]]"
+
+            # Exclude the additional brokers via configuration. However,
+            # don't throw away any ranks already excluded bythe user.
+            # Note: raises an exception if user excluded by hostname (unlikely)
+            exclude = IDset(args.conf.get("resource.exclude", default="")).set(
+                1, nbrokers
+            )
+            args.conf.update(f'resource.exclude="{exclude}"')
+
+        if args.time_limit is not None:
+            try:
+                limit = float(args.time_limit)
+                args.time_limit = limit * 60
+            except ValueError:
+                # no conversion necessary
+                pass
+
+    def update_jobspec_common(self, args, jobspec):
+        """Common jobspec update code for batch/alloc"""
+        # If args.add_brokers is being used, update jobspec task count
+        # to accurately reflect the updated task count.
+        if args.add_brokers > 0:
+            # Note: args.nodes required with add_brokers already checked above
+            total_tasks = args.nodes + args.add_brokers
+
+            # Overwrite task count with new total_tasks:
+            jobspec.tasks[0]["count"] = {"total": total_tasks}
+
+            # remove per-resource shell option which is no longer necessary:
+            del jobspec.attributes["system"]["shell"]["options"]["per-resource"]
