@@ -32,6 +32,15 @@ class Flux(Wrapper):
     Example:
         >>> flux.Flux()
         <flux.core.Flux object at 0x...>
+
+    Args:
+        uri (str): A fully-qualified native path as returned by
+            :man1:`flux-uri`, or a path-like string that references any
+            ancestor in the current hierarchy, e.g. ``/`` refers to
+            the root instance, ``..`` refers to the parent, ``../..``
+            the parent's parent and so on. See :man3:`flux_open` for more
+            details.
+        flags (int): flags as described in :man3:`flux_open`.
     """
 
     #  Thread local storage to hold a reactor_running boolean, indicating
@@ -331,18 +340,14 @@ class Flux(Wrapper):
             reactor_interrupted = True
             handle.reactor_stop(reactor)
 
-        with self.signal_watcher_create(signal.SIGINT, reactor_interrupt):
+        with self.signal_watcher_create(signal.SIGINT, reactor_interrupt) as w:
             with self.in_reactor():
                 # This signal watcher should not take a reference on reactor
                 #  o/w the reactor may not exit as expected when all other
                 #  active watchers and msghandlers are complete.
                 #
-                self.reactor_active_decref(reactor)
+                w.unref()
                 rc = self.flux_reactor_run(reactor, flags)
-                #  Re-establish signal watcher reference so reactor refcount
-                #   doesn't underflow when signal watcher is destroyed
-                #
-                self.reactor_active_incref(reactor)
             if reactor_interrupted:
                 raise KeyboardInterrupt
             Flux.raise_if_exception()
@@ -361,16 +366,6 @@ class Flux(Wrapper):
             reactor = self.get_reactor()
         self.flux_reactor_stop_error(reactor)
 
-    def reactor_incref(self, reactor=None):
-        if reactor is None:
-            reactor = self.get_reactor()
-        self.reactor_active_incref(reactor)
-
-    def reactor_decref(self, reactor=None):
-        if reactor is None:
-            reactor = self.get_reactor()
-        self.reactor_active_decref(reactor)
-
     def service_register(self, name):
         return Future(self.flux_service_register(name))
 
