@@ -19,7 +19,7 @@ import os
 import yaml
 from _flux._core import ffi
 from flux import hostlist, idset
-from flux.util import Fileref, parse_fsd, set_treedict
+from flux.util import Fileref, del_treedict, parse_fsd, set_treedict
 
 
 def _convert_jobspec_arg_to_string(jobspec):
@@ -132,6 +132,19 @@ def validate_jobspec(jobspec, require_version=None):
     return True
 
 
+def _attr_key_prepend(key):
+    """
+    Amend a key provided to setattr, getattr, etc. to prepend ``attributes.``
+    or ``attributes.system.`` if the key does not already start with one of
+    those key prefixes.
+    """
+    if not key.startswith("attributes."):
+        if not key.startswith(("user.", "system.")):
+            key = "system." + key
+        key = "attributes." + key
+    return key
+
+
 class Jobspec(object):
     top_level_keys = set(["resources", "tasks", "version", "attributes"])
 
@@ -279,6 +292,10 @@ class Jobspec(object):
             raise TypeError("count must be a mapping")
 
         count = task["count"]
+        if len(count) != 1:
+            raise ValueError("count must have exactly one key set")
+        if count.keys().isdisjoint({"per_slot", "per_resource", "total"}):
+            raise ValueError("count per_slot, per_resource, or total must be set")
         if "total" in count:
             if not isinstance(count["total"], int):
                 raise TypeError("count total must be an int")
@@ -424,7 +441,7 @@ class Jobspec(object):
     @property
     def environment(self):
         """
-        Environment of job. Defaults to ``None``.
+        Environment of job.
         """
         try:
             return self.jobspec["attributes"]["system"]["environment"]
@@ -444,35 +461,46 @@ class Jobspec(object):
         self.setattr("system.environment", environ)
 
     @property
-    def stdin(self):
+    def input(self):
         """Path to use for stdin."""
         return self._get_io_path("input", "stdin")
 
-    @stdin.setter
-    def stdin(self, path):
-        """Redirect stdin to a file given by `path`, a string or pathlib object."""
+    @input.setter
+    def input(self, path):
+        """
+        Redirect stdin to a file given by `path`, a string or pathlib object.
+        """
         self._set_io_path("input", "stdin", path)
 
     @property
-    def stdout(self):
+    def output(self):
         """Path to use for stdout."""
         return self._get_io_path("output", "stdout")
 
-    @stdout.setter
-    def stdout(self, path):
-        """Redirect stdout to a file given by `path`, a string or pathlib object."""
+    @output.setter
+    def output(self, path):
+        """
+        Redirect output to a file given by `path`, a string or pathlib object.
+        """
         self._set_io_path("output", "stdout", path)
 
     @property
-    def stderr(self):
+    def error(self):
         """Path to use for stderr."""
         return self._get_io_path("output", "stderr")
 
-    @stderr.setter
-    def stderr(self, path):
-        """Redirect stderr to a file given by `path`, a string or pathlib object."""
+    @error.setter
+    def error(self, path):
+        """
+        Redirect stderr to a file given by `path`, a string or pathlib object.
+        """
         self._set_io_path("output", "stderr", path)
 
+    # stdin, stdout, and stderr are aliases for input, output, and error:
+    stdin = input
+    stdout = output
+    stderr = error
+
     def _get_io_path(self, iotype, stream_name):
         """Get the path of a stdio stream, if set.
 
@@ -503,6 +531,61 @@ class Jobspec(object):
         self.setattr_shell_option("{}.{}.type".format(iotype, stream_name), "file")
         self.setattr_shell_option("{}.{}.path".format(iotype, stream_name), path)
 
+    @property
+    def unbuffered(self):
+        """True if std output and error are unbuffered"""
+        try:
+            return (
+                self.getattr("shell.options.output.stdout.buffer.type") == "none"
+                and self.getattr("shell.options.output.stderr.buffer.type") == "none"
+            )
+        except KeyError:
+            pass  # fall through to return False
+        return False
+
+    @unbuffered.setter
+    def unbuffered(self, value):
+        """
+        Set unbuffered mode for output in jobspec.
+
+        If True, buffer type for stdout and stderr will be set to "none" and
+        ``batch-timeout`` shell option will be set to 50ms.
+
+        If False, the buffering options for stdout and stderr will be cleared
+        from jobspec. The batch-timeout option will additionally be cleared
+        if it matches the reduced value used by the unbuffered setter.
+
+        Raises:
+            TypeError: if ``value`` is not True or False.
+        """
+        if not isinstance(value, bool):
+            raise TypeError("unbuffered must be True or False")
+
+        if value:
+            self.setattr_shell_option("output.stdout.buffer.type", "none")
+            self.setattr_shell_option("output.stderr.buffer.type", "none")
+            self.setattr_shell_option("output.batch-timeout", 0.05)
+        else:
+            try:
+                del_treedict(
+                    self.attributes,
+                    "system.shell.options.output.stdout.buffer",
+                    remove_empty=True,
+                )
+                del_treedict(
+                    self.attributes,
+                    "system.shell.options.output.stderr.buffer",
+                    remove_empty=True,
+                )
+                if self.getattr("shell.options.output.batch-timeout") == 0.05:
+                    del_treedict(
+                        self.attributes,
+                        "system.shell.options.output.batch-timeout",
+                        remove_empty=True,
+                    )
+            except KeyError:
+                pass  # Ignore keys already missing or deleted
+
     def add_file(self, path, data, perms=None, encoding=None):
         """
         Add a file to the RFC 14 "files" dictionary in Jobspec. If
@@ -514,7 +597,7 @@ class Jobspec(object):
         Args:
             path (str): path or file name to encode ``data`` as in Jobspec
             data (dict, str): content of file or a local path to load
-            perms (int): file pemissions, default 0o0600 (octal). If ``data``
+            perms (int): file permissions, default 0o0600 (octal). If ``data``
                 is a file system path, then permissions of the local file
                 system object will be used.
             encoding (str): RFC 37 compatible encoding for ``data``. None
@@ -543,8 +626,7 @@ class Jobspec(object):
 
         Raises KeyError if a component of key does not exist.
         """
-        if not key.startswith("attributes."):
-            key = "attributes." + key
+        key = _attr_key_prepend(key)
         value = self.jobspec
         for attr in key.split("."):
             value = value.get(attr)
@@ -556,11 +638,11 @@ class Jobspec(object):
         """
         set job attribute
         """
-        if not key.startswith("attributes."):
-            if not key.startswith(("user.", "system.")):
-                key = "system." + key
-            key = "attributes." + key
-        set_treedict(self.jobspec, key, val)
+        try:
+            key = _attr_key_prepend(key)
+            set_treedict(self.jobspec, key, val)
+        except TypeError as e:
+            raise TypeError(f"failed to set {key} to {val}: {e}")
 
     def setattr_shell_option(self, key, val):
         """
@@ -674,6 +756,15 @@ class Jobspec(object):
             count_dict[resource["type"]] += count
         return count_dict
 
+    def __repr__(self):
+        return (
+            f"{type(self).__name__}({self.resources}, {self.tasks}, "
+            f"attributes={self.attributes}, version={self.version})"
+        )
+
+    def __str__(self):
+        return str(self.jobspec)
+
 
 class JobspecV1(Jobspec):
     def __init__(self, resources, tasks, **kwargs):
@@ -726,6 +817,64 @@ class JobspecV1(Jobspec):
         if not isinstance(system["duration"], numbers.Number):
             raise ValueError("attributes.system.duration must be a number")
 
+        # per_slot or total required in V1 tasks.count (no per_resource)
+        for task in tasks:
+            if task["count"].keys().isdisjoint({"per_slot", "total"}):
+                raise ValueError("count per_slot or total must be set")
+
+    def _set_extra_options(
+        self,
+        duration=None,
+        environment=None,
+        env_expand=None,
+        cwd=None,
+        rlimits=None,
+        name=None,
+        input=None,
+        output=None,
+        error=None,
+        label_io=False,
+        unbuffered=False,
+        queue=None,
+        bank=None,
+    ):
+        """Process common jobspec factory args and return amended jobspec"""
+        if duration is not None:
+            self.duration = duration
+        if environment is not None:
+            self.environment = environment
+        else:
+            self.environment = dict(os.environ)
+        if env_expand is not None:
+            if not isinstance(env_expand, abc.Mapping):
+                raise ValueError("env_expand must be a mapping")
+            self.setattr_shell_option("env-expand", env_expand)
+        if cwd is not None:
+            self.cwd = cwd
+        if rlimits is not None:
+            if not isinstance(rlimits, abc.Mapping):
+                raise ValueError("rlimits must be a mapping")
+            self.setattr_shell_option("rlimit", rlimits)
+        if name is not None:
+            self.setattr("job.name", name)
+        if input is not None:
+            self.input = input
+        if output is not None and output not in ("none", "kvs"):
+            self.output = output
+            if label_io:
+                self.setattr_shell_option("output.stdout.label", True)
+        if error is not None and error not in ("none", "kvs"):
+            self.error = error
+            if label_io:
+                self.setattr_shell_option("output.stderr.label", True)
+        if unbuffered:
+            self.unbuffered = True
+        if queue is not None:
+            self.setattr("queue", queue)
+        if bank is not None:
+            self.setattr("bank", bank)
+        return self
+
     @classmethod
     # pylint: disable=too-many-branches,too-many-locals,too-many-statements
     def per_resource(
@@ -737,6 +886,7 @@ class JobspecV1(Jobspec):
         per_resource_count=None,
         gpus_per_node=None,
         exclusive=False,
+        **kwargs,
     ):
         """
         Factory function that builds a v1 jobspec from an explicit count
@@ -754,6 +904,8 @@ class JobspecV1(Jobspec):
                                 `per_resource_type`
             gpus_per_node: With nnodes, request a number of gpus per node
             exclusive: with nnodes, request whole nodes exclusively
+            **kwargs: Extra named arguments as accepted in
+                :func:`~JobspecV1.from_command`
         """
 
         #  Handle per-resource specification:
@@ -844,7 +996,7 @@ class JobspecV1(Jobspec):
         attributes = {"system": {"duration": 0}}
         if per_resource:
             set_treedict(attributes, "system.shell.options.per-resource", per_resource)
-        return cls(resources, tasks, attributes=attributes)
+        return cls(resources, tasks, attributes=attributes)._set_extra_options(**kwargs)
 
     @classmethod
     # pylint: disable=too-many-branches
@@ -856,18 +1008,62 @@ class JobspecV1(Jobspec):
         gpus_per_task=None,
         num_nodes=None,
         exclusive=False,
+        duration=None,
+        environment=None,
+        env_expand=None,
+        cwd=None,
+        rlimits=None,
+        name=None,
+        input=None,
+        output=None,
+        error=None,
+        label_io=False,
+        unbuffered=False,
+        queue=None,
+        bank=None,
     ):
         """
         Factory function that builds the minimum legal v1 jobspec.
 
-        Use setters to assign additional properties.
-
-        :param command: command to execute
-        :type command: iterable of str
-        :param num_tasks: number of MPI tasks to create
-        :param cores_per_task: number of cores to allocate per task
-        :param gpus_per_task: number of GPUs to allocate per task
-        :param num_nodes: distribute allocated tasks across N individual nodes
+        Args:
+            command (iterable of str): command to execute
+            num_tasks (int): number of tasks to create
+            cores_per_task (int): number of cores to allocate per task
+            gpus_per_task (int): number of GPUs to allocate per task
+            num_nodes (int): distribute allocated tasks across N individual
+                nodes.
+            exclusive (bool): always allocate nodes exclusively
+            duration (Number, str): assign a time limit to the job in Flux
+                Standard Duration (if str), :obj:`datetime.timedelta` or
+                Number in seconds. If not provided then the duration will
+                unlimited unless set via the :py:attr:`~JobspecV1.duration`
+                setter.
+            environment (Mapping): Set the environment for the job via a
+                mapping of environment variable name to value. If not
+                provided then the environment will be initialized using
+                :obj:`os.environ`.
+            env_expand (Mapping): A  mapping of environment variables that
+                contain mustache templates to be expanded by the job shell
+                at runtime. (See the :manpage:`flux-run(1)` MUSTACHE
+                TEMPLATES section for more info)
+            rlimits (Mapping): Set process resource limits for the job via
+                a mapping of limit name to value, where a value of -1 is
+                taken as unlimited. E.g. ``{"nofile": 12000}``.
+            cwd (str): Set the current working directory for the job. If
+                unset, then a working directory may be set using the
+                :attr:`~JobspecV1.cwd` setter.
+            name (str): Set a job name.
+            input (str, :obj:`os.PathLike`): Set job input to a file path.
+            output (str, :obj:`os.PathLike`): Set job output to a file path.
+                ``stderr`` will be copied to the same path as ``stdout``
+                by default unless it is set separately.
+            error: (str, :obj:`os.PathLike`): Set job stderr to a file path.
+            label_io (bool): For file output, label output with the source
+                task ids. Default is False.
+            unbuffered (bool): Disable output buffering as much as
+                practical.
+            queue (str): Set the queue for the job.
+            bank (str): Set the bank for the job.
         """
         if not isinstance(num_tasks, int) or num_tasks < 1:
             raise ValueError("task count must be a integer >= 1")
@@ -905,7 +1101,21 @@ class JobspecV1(Jobspec):
         resources = [resource_section]
         tasks = [{"command": command, "slot": "task", "count": task_count_dict}]
         attributes = {"system": {"duration": 0}}
-        return cls(resources, tasks, attributes=attributes)
+        return cls(resources, tasks, attributes=attributes)._set_extra_options(
+            duration=duration,
+            environment=environment,
+            env_expand=env_expand,
+            cwd=cwd,
+            rlimits=rlimits,
+            name=name,
+            input=input,
+            output=output,
+            error=error,
+            label_io=label_io,
+            unbuffered=unbuffered,
+            queue=queue,
+            bank=bank,
+        )
 
     @classmethod
     def from_batch_command(
@@ -920,6 +1130,7 @@ class JobspecV1(Jobspec):
         broker_opts=None,
         exclusive=False,
         conf=None,
+        **kwargs,
     ):
         """
         Create a Jobspec describing a nested Flux instance controlled by
@@ -956,6 +1167,8 @@ class JobspecV1(Jobspec):
                 jobspec 'files' (RFC 37 File Archive) attribute as `conf.json`,
                 and broker_opts will be extended to add
                 `-c{{tmpdir}}/conf.json`
+            **kwargs: Extra named arguments as accepted in
+                :func:`~JobspecV1.from_command`
         """
         if not script.startswith("#!"):
             raise ValueError(f"{jobname} does not appear to start with '#!'")
@@ -969,10 +1182,11 @@ class JobspecV1(Jobspec):
             broker_opts=broker_opts,
             exclusive=exclusive,
             conf=conf,
+            name=jobname,
+            **kwargs,
         )
         #  Copy script contents into jobspec
         jobspec.add_file("script", script, perms=0o700, encoding="utf-8")
-        jobspec.setattr("system.job.name", jobname)
         return jobspec
 
     @classmethod
@@ -986,6 +1200,7 @@ class JobspecV1(Jobspec):
         broker_opts=None,
         exclusive=False,
         conf=None,
+        **kwargs,
     ):
         """
         Create a Jobspec describing a nested Flux instance controlled by
@@ -1016,6 +1231,8 @@ class JobspecV1(Jobspec):
                 jobspec 'files' (RFC 37 File Archive) attribute as `conf.json`,
                 and broker_opts will be extended to add
                 `-c{{tmpdir}}/conf.json`
+            **kwargs: Extra named arguments as accepted in
+                :func:`~JobspecV1.from_command`
         """
         broker_opts = [] if broker_opts is None else broker_opts
         if conf is not None:
@@ -1027,9 +1244,12 @@ class JobspecV1(Jobspec):
             gpus_per_task=gpus_per_slot,
             num_nodes=num_nodes,
             exclusive=exclusive,
+            **kwargs,
         )
         jobspec.setattr_shell_option("per-resource.type", "node")
         jobspec.setattr_shell_option("mpi", "none")
+        #  Default exit-timeout=none
+        jobspec.setattr_shell_option("exit-timeout", "none")
         if conf is not None:
             jobspec.add_file("conf.json", conf)
         return jobspec
