@@ -24,7 +24,7 @@ import stat
 import sys
 import threading
 import traceback
-from collections import namedtuple
+from collections import abc, namedtuple
 from datetime import datetime, timedelta
 from operator import attrgetter
 from pathlib import Path, PurePosixPath
@@ -205,6 +205,32 @@ def set_treedict(in_dict, key, val):
         in_dict[key] = val
 
 
+def del_treedict(in_dict, key, remove_empty=False):
+    """
+    ``del_treedict(d, "a.b.c")`` is like ``del d[a][b][c]``
+
+    Args:
+        in_dict (Mapping): dict in which to remove ``key``
+        key (str): dotted key to remove
+        remove_empty (bool): If True, remove empty dictionaries that result
+            from deletion of ``key``.
+
+    Raises:
+        KeyError: a path component of ``key`` does not exist.
+    """
+    path = key.split(".", 1)
+    if len(path) == 2:
+        del_treedict(in_dict[path[0]], path[1], remove_empty=remove_empty)
+        if (
+            remove_empty
+            and isinstance(in_dict[path[0]], abc.Mapping)
+            and len(in_dict[path[0]]) == 0
+        ):
+            del in_dict[path[0]]
+    else:
+        del in_dict[key]
+
+
 class TreedictAction(argparse.Action):
     """
     argparse action that returns a dictionary from a set of key=value option
@@ -244,6 +270,13 @@ class FilterActionSetUpdate(argparse.Action):
         getattr(namespace, self.dest).update(values)
 
 
+class FilterActionUser(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        setattr(namespace, "filtered", True)
+        setattr(namespace, "filtereduser", True)
+        setattr(namespace, self.dest, values)
+
+
 # pylint: disable=redefined-builtin
 class FilterTrueAction(argparse.Action):
     def __init__(
@@ -618,7 +651,9 @@ class OutputFormat:
                 return kwargs[field_name], None
             return super().get_field(field_name, args, kwargs)
 
-    def __init__(self, fmt, headings=None, prepend="0."):
+    def __init__(
+        self, fmt, headings=None, prepend="0.", nullify_expansion_sentinel=False
+    ):
         """
         Parse the input format ``fmt`` with string.Formatter.
         Save off the fields and list of format tokens for later use,
@@ -628,6 +663,9 @@ class OutputFormat:
             headings (dict): Set a mapping of field name to header string.
             prepend (str): Prepend each field with a string. (Default is
                 "0.", so ``{f1} {f2}`` becomes ``{0.f1} {0.f2}``.
+            nullify_expansion_sentinel (bool): Replace fields with an expansion
+                sentinel (``+:``) with just the field, e.g. ``+:{foo:<10.10}``
+                is replaced with ``{foo}``.
         """
         if headings is not None:
             self.headings = headings
@@ -813,7 +851,11 @@ class OutputFormat:
         return formatter.format(self.header_format(), **self.headings)
 
     def get_format_prepended(
-        self, prepend, except_fields=None, include_sort_prefix=True
+        self,
+        prepend,
+        except_fields=None,
+        include_sort_prefix=True,
+        nullify_expansion_sentinel=False,
     ):
         """
         Return the format string, ensuring that the string in "prepend"
@@ -825,6 +867,9 @@ class OutputFormat:
                 the format.
             include_sort_prefix (bool): If format specifies a list of sort
                 keys, include them in a ``sort:`` prefix. Default: True
+            nullify_expansion_sentinel (bool): If format specifies an expansion
+                prefix ``+:``, then substitute the field without any width
+                and precision, e.g. ``+:{foo:<10.10}`` becomes ``{foo}``.
         """
         if except_fields is None:
             except_fields = []
@@ -833,11 +878,19 @@ class OutputFormat:
             # Skip this field if it is in except_fields
             if field in except_fields:
                 # Preserve any format "prefix" (i.e. the text):
-                lst.append(text)
+                # Unless it is whitespace or a sentinel (+:,  etc):
+                result = text.strip()
+                if result and result not in ("+:", "?:", "?+:"):
+                    lst.append(text)
                 continue
             # If field doesn't have 'prepend' then add it
             if field and not field.startswith(prepend):
                 field = prepend + field
+            # If caller has requested `+:` prefix is to be nullified,
+            # and that prefix exists, then reset text and spec:
+            if nullify_expansion_sentinel and text.endswith("+:"):
+                text = ""
+                spec = ""
             lst.append(self._fmt_tuple(text, field, spec, conv))
         if include_sort_prefix:
             prefix = self._sort_prefix()
@@ -864,17 +917,22 @@ class OutputFormat:
             return self._sort_prefix() + fmt
         return fmt
 
-    def copy(self, except_fields=None):
+    def copy(self, except_fields=None, nullify_expansion=False):
         """
         Return a copy of the current formatter, optionally with some
         fields removed
 
         Args:
             except_fields (list): List of fields to remove from result.
+            nullify_expansion (bool): If True, replace any fields in original
+                that have an expansion sentinel with just the field, e.g.
+                ``+:{foo:>5.5}`` becomes ``{foo}`` in the copy.
         """
         cls = self.__class__
         return cls(
-            self.get_format_prepended("", except_fields),
+            self.get_format_prepended(
+                "", except_fields, nullify_expansion_sentinel=nullify_expansion
+            ),
             headings=self.headings,
             prepend=self.prepend,
         )
@@ -1110,7 +1168,9 @@ class Deduplicator:
     """
 
     def __init__(self, formatter, except_fields=None, combine=None):
-        self.formatter = formatter.copy(except_fields=except_fields)
+        self.formatter = formatter.copy(
+            except_fields=except_fields, nullify_expansion=True
+        )
         self.combine = combine
         self.hash = {}
         self.items = []
