@@ -458,13 +458,6 @@ enum {
 
 };
 
-
-
-enum {
-    FLUX_REACTOR_SIGCHLD = 1,
-
-};
-
 flux_reactor_t *flux_reactor_create (int flags);
 void flux_reactor_destroy (flux_reactor_t *r);
 void flux_reactor_incref (flux_reactor_t *r);
@@ -478,12 +471,12 @@ void flux_reactor_stop_error (flux_reactor_t *r);
 double flux_reactor_now (flux_reactor_t *r);
 void flux_reactor_now_update (flux_reactor_t *r);
 double flux_reactor_time (void);
-# 721 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 714 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_watcher_f)(flux_reactor_t *r,
                                flux_watcher_t *w,
                                int revents,
                                void *arg);
-# 733 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 726 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_watcher_set_priority (flux_watcher_t *w, int priority);
 
 void flux_watcher_start (flux_watcher_t *w);
@@ -563,17 +556,6 @@ flux_watcher_t *flux_idle_watcher_create (flux_reactor_t *r,
 
 
 
-flux_watcher_t *flux_child_watcher_create (flux_reactor_t *r,
-                                           int pid,
-                                           bool trace,
-                                           flux_watcher_f cb,
-                                           void *arg);
-int flux_child_watcher_get_rpid (flux_watcher_t *w);
-int flux_child_watcher_get_rstatus (flux_watcher_t *w);
-
-
-
-
 flux_watcher_t *flux_signal_watcher_create (flux_reactor_t *r,
                                             int signum,
                                             flux_watcher_f cb,
@@ -592,7 +574,7 @@ flux_watcher_t *flux_stat_watcher_create (flux_reactor_t *r,
 int flux_stat_watcher_get_rstat (flux_watcher_t *w,
                                  struct stat *stat,
                                  struct stat *prev);
-# 866 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 848 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_msg_handler flux_msg_handler_t;
 
 typedef void (*flux_msg_handler_f)(flux_t *h, flux_msg_handler_t *mh,
@@ -642,7 +624,7 @@ int flux_dispatch_requeue (flux_t *h);
 
 
 flux_watcher_t *flux_get_handle_watcher (flux_t *h);
-# 946 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 928 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef flux_t *(connector_init_f)(const char *uri,
                                    int flags,
                                    flux_error_t *errp);
@@ -675,7 +657,7 @@ flux_t *flux_handle_create (void *impl,
                             const struct flux_handle_ops *ops,
                             int flags);
 void flux_handle_destroy (flux_t *hp);
-# 1009 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 991 "/__w/flux-python/flux-python/src/_core_clean.h"
 struct flux_msglist *flux_msglist_create (void);
 void flux_msglist_destroy (struct flux_msglist *l);
 
@@ -689,10 +671,10 @@ const flux_msg_t *flux_msglist_next (struct flux_msglist *l);
 const flux_msg_t *flux_msglist_last (struct flux_msglist *l);
 
 int flux_msglist_count (struct flux_msglist *l);
-# 1030 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1012 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_msglist_pollevents (struct flux_msglist *l);
 int flux_msglist_pollfd (struct flux_msglist *l);
-# 1065 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1047 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_request_decode (const flux_msg_t *msg,
                          const char **topic,
                          const char **s);
@@ -729,11 +711,11 @@ flux_msg_t *flux_request_encode (const char *topic, const char *s);
 flux_msg_t *flux_request_encode_raw (const char *topic,
                                      const void *data,
                                      size_t len);
-# 1136 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1118 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode (const flux_msg_t *msg,
                           const char **topic,
                           const char **s);
-# 1148 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1130 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode_raw (const flux_msg_t *msg,
                               const char **topic,
                               const void **data,
@@ -798,11 +780,11 @@ int flux_respond_error (flux_t *h,
                         const flux_msg_t *request,
                         int errnum,
                         const char *errstr);
-# 1240 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1222 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_control_encode (int type, int status);
 
 int flux_control_decode (const flux_msg_t *msg, int *type, int *status);
-# 1270 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1252 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_RPC_NORESPONSE = 1,
     FLUX_RPC_STREAMING = 2,
@@ -853,7 +835,7 @@ uint32_t flux_rpc_get_matchtag (flux_future_t *f);
 
 
 uint32_t flux_rpc_get_nodeid (flux_future_t *f);
-# 1347 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1329 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum event_flags {
     FLUX_EVENT_PRIVATE = 1,
 };
@@ -944,7 +926,7 @@ flux_future_t *flux_event_publish_raw (flux_t *h,
 
 
 int flux_event_publish_get_seq (flux_future_t *f, int *seq);
-# 1467 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1449 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_MODSTATE_INIT = 0,
     FLUX_MODSTATE_RUNNING = 1,
@@ -970,7 +952,7 @@ bool flux_module_debug_test (flux_t *h, int flag, bool clear);
 
 
 int flux_module_set_running (flux_t *h);
-# 1539 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1521 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_attr_get (flux_t *h, const char *name);
 
 
@@ -1009,7 +991,7 @@ const char *flux_get_hostbyrank (flux_t *h, uint32_t rank);
 
 
 int flux_get_rankbyhost (flux_t *h, const char *host);
-# 1591 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1573 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_hostmap_lookup (flux_t *h,
                            const char *targets,
                            flux_error_t *errp);
@@ -1020,7 +1002,7 @@ char *flux_hostmap_lookup (flux_t *h,
 
 
 int flux_get_instance_starttime (flux_t *h, double *starttime);
-# 1632 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1611 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_log_f)(const char *buf, int len, void *arg);
 
 
@@ -1072,7 +1054,7 @@ void flux_llog (void *arg,
                 int level,
                 const char *fmt,
                 va_list ap);
-# 1711 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1690 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum flux_conf_flags {
     FLUX_CONF_INSTALLED=0,
     FLUX_CONF_INTREE=1,
@@ -1126,7 +1108,7 @@ int flux_conf_unpack (const flux_conf_t *conf,
                       flux_error_t *error,
                       const char *fmt,
                       ...);
-# 1795 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1774 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_continuation_f)(flux_future_t *f, void *arg);
 
 int flux_future_then (flux_future_t *f,
@@ -1196,7 +1178,7 @@ const char * flux_future_first_child (flux_future_t *cf);
 const char * flux_future_next_child (flux_future_t *cf);
 
 flux_future_t *flux_future_get_child (flux_future_t *cf, const char *name);
-# 1877 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1856 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_future_and_then (flux_future_t *f,
                                      flux_continuation_f cb,
                                      void *arg);
@@ -1227,13 +1209,13 @@ void flux_future_continue_error (flux_future_t *prev,
 int flux_future_fulfill_next (flux_future_t *prev,
                               void *result,
                               flux_free_f free_fn);
-# 1938 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1917 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_barrier (flux_t *h, const char *name, int nprocs);
-# 1980 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1959 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_register (flux_t *h, const char *name);
-# 1992 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1971 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_unregister (flux_t *h, const char *name);
-# 2044 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2023 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_core_version_string (void);
 
 
@@ -1242,7 +1224,7 @@ const char *flux_core_version_string (void);
 
 
 int flux_core_version (int *major, int *minor, int *patch);
-# 2081 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2060 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_PLUGIN_RTLD_LAZY = 1,
     FLUX_PLUGIN_RTLD_NOW = 2,
@@ -1320,7 +1302,7 @@ flux_plugin_f flux_plugin_match_handler (flux_plugin_t *p, const char *topic);
 int flux_plugin_register (flux_plugin_t *p,
                           const char *name,
                           const struct flux_plugin_handler t[]);
-# 2168 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2147 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_aux_set (flux_plugin_t *p,
                          const char *key,
                          void *val,
@@ -1389,15 +1371,15 @@ int flux_plugin_arg_vunpack (flux_plugin_arg_t *args,
                              int flags,
                              const char *fmt,
                              va_list ap);
-# 2244 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2223 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_call (flux_plugin_t *p,
                       const char *name,
                       flux_plugin_arg_t *args);
-# 2255 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2234 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_load_dso (flux_plugin_t *p, const char *path);
-# 2287 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2266 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_sync_create (flux_t *h, double minimum);
-# 2318 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2297 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_disconnect_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 
 
@@ -1417,7 +1399,7 @@ bool flux_cancel_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 int flux_msglist_cancel (flux_t *h,
                          struct flux_msglist *l,
                          const flux_msg_t *msg);
-# 2386 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2365 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_stats_count (flux_t *h, const char *name, ssize_t count);
 
 
@@ -1453,10 +1435,10 @@ void flux_stats_set_prefix (flux_t *h, const char *fmt, ...);
 
 
 bool flux_stats_enabled (flux_t *h, const char *metric);
-# 2469 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2448 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvsdir flux_kvsdir_t;
 typedef struct flux_kvsitr flux_kvsitr_t;
-# 2484 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2463 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_kvsdir_t *flux_kvsdir_create (flux_t *handle,
                                    const char *rootref,
                                    const char *key,
@@ -1504,7 +1486,7 @@ const char *flux_kvsdir_rootref (const flux_kvsdir_t *dir);
 
 
 char *flux_kvsdir_key_at (const flux_kvsdir_t *dir, const char *key);
-# 2559 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2538 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_lookup (flux_t *h,
                                 const char *ns,
                                 int flags,
@@ -1531,14 +1513,14 @@ const char *flux_kvs_lookup_get_key (flux_future_t *f);
 
 
 int flux_kvs_lookup_cancel (flux_future_t *f);
-# 2613 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2592 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_getroot (flux_t *h, const char *ns, int flags);
-# 2622 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2601 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_kvs_getroot_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_getroot_get_blobref (flux_future_t *f, const char **blobref);
 int flux_kvs_getroot_get_sequence (flux_future_t *f, int *seq);
 int flux_kvs_getroot_get_owner (flux_future_t *f, uint32_t *owner);
-# 2654 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2633 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvs_txn flux_kvs_txn_t;
 
 flux_kvs_txn_t *flux_kvs_txn_create (void);
@@ -1589,7 +1571,7 @@ int flux_kvs_txn_symlink (flux_kvs_txn_t *txn,
 int flux_kvs_txn_clear (flux_kvs_txn_t *txn);
 
 bool flux_kvs_txn_is_empty (flux_kvs_txn_t *txn);
-# 2753 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2732 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_commit_flags {
     FLUX_KVS_NO_MERGE = 1,
     FLUX_KVS_TXN_COMPACT = 2,
@@ -1601,32 +1583,25 @@ flux_future_t *flux_kvs_commit (flux_t *h,
                                 int flags,
                                 flux_kvs_txn_t *txn);
 
-flux_future_t *flux_kvs_fence (flux_t *h,
-                               const char *ns,
-                               int flags,
-                               const char *name,
-                               int nprocs,
-                               flux_kvs_txn_t *txn);
-
 
 int flux_kvs_commit_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_commit_get_rootref (flux_future_t *f, const char **rootref);
 int flux_kvs_commit_get_sequence (flux_future_t *f, int *rootseq);
-# 2814 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2786 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_copy (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2831 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2803 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_move (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2854 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2826 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_op {
     FLUX_KVS_READDIR = 1,
     FLUX_KVS_READLINK = 2,
@@ -1639,7 +1614,7 @@ enum kvs_op {
     FLUX_KVS_WATCH_APPEND = 256,
     FLUX_KVS_STREAM = 512
 };
-# 2876 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2848 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_namespace_create (flux_t *h,
                                           const char *ns,
                                           uint32_t owner,
@@ -1657,13 +1632,7 @@ flux_future_t *flux_kvs_namespace_remove (flux_t *h, const char *ns);
 
 int flux_kvs_get_version (flux_t *h, const char *ns, int *versionp);
 int flux_kvs_wait_version (flux_t *h, const char *ns, int version);
-
-
-
-
-
-int flux_kvs_dropcache (flux_t *h);
-# 2927 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2893 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum job_submit_flags {
     FLUX_JOB_PRE_SIGNED = 1,
     FLUX_JOB_DEBUG = 2,
@@ -1741,10 +1710,10 @@ typedef uint64_t flux_jobid_t;
 
 
 int flux_job_id_parse (const char *s, flux_jobid_t *id);
-# 3013 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2979 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_id_encode (flux_jobid_t id, const char *type,
                         char *buf, size_t bufsz);
-# 3024 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2990 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_job_statetostr (flux_job_state_t state, const char *fmt);
 
 
@@ -1858,11 +1827,11 @@ flux_future_t *flux_job_result (flux_t *h, flux_jobid_t id, int flags);
 
 int flux_job_result_get (flux_future_t *f,
                          const char **json_str);
-# 3155 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3121 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_result_get_unpack (flux_future_t *f, const char *fmt, ...);
-# 3169 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3135 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_timeleft (flux_t *h, flux_error_t *errp, double *timeleft);
-# 3185 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3151 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_unwrap_string (const char *in,
                           bool verify,
                           uint32_t *userid,
@@ -1874,7 +1843,7 @@ char *flux_unwrap_string (const char *in,
 
 
 int flux_job_waitstatus_to_exitcode (int waitstatus, flux_error_t *errp);
-# 3220 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3186 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_jobspec1 flux_jobspec1_t;
 typedef flux_error_t flux_jobspec1_error_t;
 
@@ -1972,7 +1941,7 @@ char *flux_jobspec1_encode (flux_jobspec1_t *jobspec, size_t flags);
 
 flux_jobspec1_t *flux_jobspec1_decode (const char *s,
                                        flux_jobspec1_error_t *error);
-# 3331 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3297 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_jobspec1_t *flux_jobspec1_from_command (int argc,
                                              char **argv,
                                              char **env,
@@ -1984,7 +1953,7 @@ flux_jobspec1_t *flux_jobspec1_from_command (int argc,
 
 
 void flux_jobspec1_destroy (flux_jobspec1_t *jobspec);
-# 3387 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3353 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_command flux_cmd_t;
 
 
@@ -2068,14 +2037,14 @@ const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
 
 int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
 const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
-# 3483 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3449 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
-# 3520 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3486 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
 const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
-# 3541 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3507 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_subprocess flux_subprocess_t;
-# 3553 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3519 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef enum {
     FLUX_SUBPROCESS_INIT,
     FLUX_SUBPROCESS_RUNNING,
@@ -2099,7 +2068,7 @@ enum {
 
 
     FLUX_SUBPROCESS_FLAGS_FORK_EXEC = 4,
-# 3586 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3552 "/__w/flux-python/flux-python/src/_core_clean.h"
     FLUX_SUBPROCESS_FLAGS_LOCAL_UNBUF = 8,
 };
 
@@ -2116,7 +2085,7 @@ typedef void (*flux_subprocess_credit_f) (flux_subprocess_t *p,
                                           const char *stream,
                                           int bytes);
 typedef void (*flux_subprocess_hook_f) (flux_subprocess_t *p, void *arg);
-# 3614 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3580 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct {
     flux_subprocess_f on_completion;
 
@@ -2151,7 +2120,7 @@ typedef void (*subprocess_log_f)(void *arg,
                                  int level,
                                  const char *fmt,
                                  va_list args);
-# 3670 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3636 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2186,7 +2155,7 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
 
 void flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
 void flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
-# 3714 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3680 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_write (flux_subprocess_t *p,
                            const char *stream,
                            const char *buf,
@@ -2198,11 +2167,11 @@ int flux_subprocess_write (flux_subprocess_t *p,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3742 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3708 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read (flux_subprocess_t *p,
                           const char *stream,
                           const char **bufp);
-# 3768 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3734 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read_line (flux_subprocess_t *p,
                                const char *stream,
                                const char **bufp);
@@ -2213,10 +2182,10 @@ int flux_subprocess_read_line (flux_subprocess_t *p,
 int flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                        const char *stream,
                                        const char **bufp);
-# 3787 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3753 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_subprocess_read_stream_closed (flux_subprocess_t *p,
                                          const char *stream);
-# 3805 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3771 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_getline (flux_subprocess_t *p,
                              const char *stream,
                              const char **bufp);
@@ -2310,7 +2279,7 @@ void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
 
 void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
 void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
-# 3913 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3879 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
